django-mutexevent
=================

[![Build Status](https://travis-ci.org/lovasb/django-mutexevent.png?branch=master)](https://travis-ci.org/lovasb/django-mutexevent)

http://en.wikipedia.org/wiki/Mutually_exclusive_events
